// Do not edit this file to make sure your plugin works in the saysimple platform
import content from "./content.vue";
import settings from "./settings.vue";
import VueCompositionAPI from "@vue/composition-api";
import Vue from "vue";
import { locales } from "./locales";
import { faIcons } from "./faIcons";
import { icon } from "./icon";

// pkg needs to be fetched using require
// eslint-disable-next-line @typescript-eslint/no-var-requires
const pkg = require("../package.json");

Vue.use(VueCompositionAPI);

const installers = new Map();

// install function executed by Vue.use()
function installer(name, component) {
    // Prevent having multiple installers for a single component
    if (installers.has(name)) {
        return installers.get(name);
    }

    // Registers component with vue under the name `plugin-appName-name`
    function install(Vue) {
        if (install.installed) {
            return;
        }
        install.installed = true;
        Vue.use(VueCompositionAPI);
        Vue.component(`plugin-${pkg.saysimple.name}-${name}`, component);
    }

    installers.set(name, install);
    return install;
}

function prefixLocales(locales) {
    return Object.entries(locales).reduce(
        (prefixedLocales, [language, messages]) => {
            prefixedLocales[language] = {
                [`@app/${toKebabCase(pkg.saysimple.name)}`]: messages,
            };

            return prefixedLocales;
        },
        {}
    );
}

function toKebabCase(str) {
    return (
        str &&
        str
            .match(
                /[A-Z]{2,}(?=[A-Z][a-z]+[0-9]*|\b)|[A-Z]?[a-z]+[0-9]*|[A-Z]|[0-9]+/g
            )
            .map((x) => x.toLowerCase())
            .join("-")
    );
}

// Inject install function into component - allows component
// to be registered via Vue.use() as well as Vue.component()
content.install = installer("content", content);
settings.install = installer("settings", settings);

export default {
    name: pkg.saysimple.name,
    plugin: {
        name: pkg.name,
        version: pkg.version,
        saysimple: {
            icon,
            ...pkg.saysimple,
        },
    },
    components: {
        settings,
        content,
    },
    locales: prefixLocales(locales),
    faIcons,
};
